#include "commonssl.h"
#include "common.h"
#include <openssl/err.h>


BIO *bio_err=0;
static void sigpipe_handle(int x);

/* A simple error routine*/
int err_exit(string)
  char *string;
  {
	fprintf(stderr,"%s\n",string);
	exit(STATE_UNKNOWN);
  }

/* Print SSL errors*/
int berr_exit(string)
  char *string;
  {
	BIO_printf(bio_err,"%s\n",string);
	ERR_print_errors(bio_err);
	exit(STATE_CRITICAL);
  }

static void sigpipe_handle(int x){
}

SSL_CTX *initialize_ctx()
  {
    SSL_METHOD *meth;
    SSL_CTX *ctx;
    
    if(!bio_err){
      /* Global system initialization*/
      SSL_library_init();
      SSL_load_error_strings();
      
      /* An error write context */
      bio_err=BIO_new_fp(stderr,BIO_NOCLOSE);
    }

    /* Set up a SIGPIPE handler */
    signal(SIGPIPE,sigpipe_handle);
    
    /* Create our context*/
    meth=SSLv23_method();
    ctx=SSL_CTX_new(meth);

    /* Load the CAs we trust*/
    if(!(SSL_CTX_load_verify_locations(ctx,
      CA_LIST,0)))
      berr_exit("Can't read CA list");
#if (OPENSSL_VERSION_NUMBER < 0x00905100L)
    SSL_CTX_set_verify_depth(ctx,1);
#endif
    
    return ctx;
  }
     
void destroy_ctx(ctx)
  SSL_CTX *ctx;
  {
    SSL_CTX_free(ctx);
  }

/* Check that the common name matches the
   host name*/
void check_cert(ssl,host)
  SSL *ssl;
  char *host;
  {
    X509 *peer;
    char peer_CN[256];
    
    if(SSL_get_verify_result(ssl)!=X509_V_OK){
	err_exit("Certificate doesn't verify");
    }

    /*Check the cert chain. The chain length
      is automatically checked by OpenSSL when
      we set the verify depth in the ctx */

    /*Check the common name*/
    peer=SSL_get_peer_certificate(ssl);
    X509_NAME_get_text_by_NID
      (X509_get_subject_name(peer),
      NID_commonName, peer_CN, 256);
    if(strcasecmp(peer_CN,host)){
	err_exit("Common name doesn't match host name");
    }
  }

